detect_linearization

Function detect_linearization 

pub fn detect_linearization(data: &[u8]) -> Option<LinearizationParams>
Detect whether the given PDF data represents a linearized PDF, and if so, parse and return the linearization parameters.

This checks if the first indirect object in the file contains a /Linearized key.