read_linearization

Function read_linearization 

pub fn read_linearization(doc: &PdfDocument) -> Option<LinearizationParams>
Alternative API that works from a parsed PdfDocument.

Finds the first object (usually obj 1) and checks for /Linearized. This re-parses from the raw data since the linearization dict is always the first indirect object in the file.