pub struct LayoutLine {
pub text: String,
pub x_offset: f64,
pub y_offset: f64,
pub width: f64,
pub word_spacing: f64,
}Expand description
A laid-out line of text.
Fields
text: StringThe text content of this line.
x_offset: f64X offset from the left edge of the bounding box.
y_offset: f64Y offset from the top of the bounding box (positive downward in layout coords).
width: f64Width of the text in this line (in points).
word_spacing: f64Extra word spacing for justified text.